==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/hu/islamic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ez a negyedév",
	"field-quarter-short-relative+1": "következő negyedév",
	"field-tue-relative+-1": "előző kedd",
	"field-year": "év",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "ez a szerda",
	"field-wed-relative+1": "következő szerda",
	"timeFormat-short": "H:mm",
	"field-minute": "perc",
	"field-month-narrow-relative+-1": "előző hónap",
	"field-tue-narrow-relative+0": "ez a kedd",
	"field-tue-narrow-relative+1": "következő kedd",
	"field-thu-short-relative+0": "ez a csütörtök",
	"field-day-short-relative+-1": "tegnap",
	"field-thu-short-relative+1": "következő csütörtök",
	"field-day-relative+0": "ma",
	"field-day-short-relative+-2": "tegnapelőtt",
	"field-day-relative+1": "holnap",
	"field-week-narrow-relative+0": "ez a hét",
	"field-day-relative+2": "holnapután",
	"field-week-narrow-relative+1": "következő hét",
	"field-wed-narrow-relative+-1": "előző szerda",
	"field-year-narrow": "év",
	"field-year-narrow-relative+0": "ez az év",
	"field-tue-relative+0": "ez a kedd",
	"field-year-narrow-relative+1": "következő év",
	"field-tue-relative+1": "következő kedd",
	"field-second-short": "másodperc",
	"dayPeriods-format-narrow-am": "de.",
	"dateFormatItem-MMMd": "MMM d.",
	"dayPeriods-format-abbr-am": "de.",
	"field-week-relative+0": "ez a hét",
	"field-month-relative+0": "ez a hónap",
	"field-week-relative+1": "következő hét",
	"field-month-relative+1": "következő hónap",
	"field-sun-narrow-relative+0": "ez a vasárnap",
	"timeFormat-medium": "H:mm:ss",
	"field-mon-short-relative+0": "ez a hétfő",
	"field-sun-narrow-relative+1": "következő vasárnap",
	"field-mon-short-relative+1": "következő hétfő",
	"field-second-relative+0": "most",
	"dateFormatItem-yyyyQQQ": "G y. QQQ",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"eraNames": [
		"MF"
	],
	"dayPeriods-standAlone-abbr-pm": "du.",
	"field-month-short": "hónap",
	"dateFormatItem-GyMMMEd": "G y. MMM d., E",
	"dateFormatItem-yyyyMd": "G y. MM. dd.",
	"field-day": "nap",
	"field-year-relative+-1": "előző év",
	"dayPeriods-format-wide-am": "de.",
	"field-sat-short-relative+-1": "előző szombat",
	"field-hour-relative+0": "ebben az órában",
	"dateFormatItem-yyyyMEd": "G y. MM. dd., E",
	"field-wed-relative+-1": "előző szerda",
	"field-sat-narrow-relative+-1": "előző szombat",
	"field-second": "másodperc",
	"days-standAlone-narrow": [
		"V",
		"H",
		"K",
		"Sz",
		"Cs",
		"P",
		"Sz"
	],
	"dayPeriods-standAlone-wide-pm": "du.",
	"dateFormat-long": "G y. MMMM d.",
	"dateFormatItem-GyMMMd": "G y. MMM d.",
	"field-quarter": "negyedév",
	"field-week-short": "hét",
	"field-day-narrow-relative+0": "ma",
	"field-day-narrow-relative+1": "holnap",
	"field-day-narrow-relative+2": "holnapután",
	"quarters-standAlone-wide": [
		"1. negyedév",
		"2. negyedév",
		"3. negyedév",
		"4. negyedév"
	],
	"days-format-narrow": [
		"V",
		"H",
		"K",
		"Sz",
		"Cs",
		"P",
		"Sz"
	],
	"field-tue-short-relative+0": "ez a kedd",
	"field-tue-short-relative+1": "következő kedd",
	"field-month-short-relative+-1": "előző hónap",
	"field-mon-relative+-1": "előző hétfő",
	"dateFormatItem-GyMMM": "G y. MMM",
	"field-month": "hónap",
	"field-day-narrow": "nap",
	"field-minute-short": "perc",
	"field-dayperiod": "napszak",
	"field-sat-short-relative+0": "ez a szombat",
	"field-sat-short-relative+1": "következő szombat",
	"dayPeriods-format-narrow-pm": "du.",
	"dateFormat-medium": "G y. MMM d.",
	"dateFormatItem-yyyyMMMM": "G y. MMMM",
	"eraAbbr": [
		"MF"
	],
	"quarters-standAlone-abbr": [
		"N1",
		"N2",
		"N3",
		"N4"
	],
	"dayPeriods-format-abbr-pm": "du.",
	"dateFormatItem-yyyyM": "G y. MM.",
	"field-second-narrow": "másodperc",
	"field-mon-relative+0": "ez a hétfő",
	"field-mon-relative+1": "következő hétfő",
	"field-day-narrow-relative+-1": "tegnap",
	"field-year-short": "év",
	"field-day-narrow-relative+-2": "tegnapelőtt",
	"field-quarter-relative+-1": "előző negyedév",
	"dateFormatItem-yyyyMMMd": "G y. MMM d.",
	"dayPeriods-standAlone-narrow-am": "de.",
	"field-week-narrow-relative+-1": "előző hét",
	"days-format-short": [
		"V",
		"H",
		"K",
		"Sze",
		"Cs",
		"P",
		"Szo"
	],
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"dayPeriods-format-wide-pm": "du.",
	"field-sat-relative+-1": "előző szombat",
	"dateFormatItem-Md": "M. d.",
	"field-hour": "óra",
	"months-format-wide": [
		"Moharrem",
		"Safar",
		"Rébi el avvel",
		"Rébi el accher",
		"Dsemádi el avvel",
		"Dsemádi el accher",
		"Redseb",
		"Sabán",
		"Ramadán",
		"Sevvál",
		"Dsül kade",
		"Dsül hedse"
	],
	"dateFormat-full": "G y. MMMM d., EEEE",
	"field-month-relative+-1": "előző hónap",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "negyedév",
	"field-sat-narrow-relative+0": "ez a szombat",
	"field-fri-relative+0": "ez a péntek",
	"field-sat-narrow-relative+1": "következő szombat",
	"field-fri-relative+1": "következő péntek",
	"field-month-narrow-relative+0": "ez a hónap",
	"field-month-narrow-relative+1": "következő hónap",
	"field-sun-short-relative+0": "ez a vasárnap",
	"field-sun-short-relative+1": "következő vasárnap",
	"field-week-relative+-1": "előző hét",
	"field-quarter-short-relative+-1": "előző negyedév",
	"months-format-abbr": [
		"Moh.",
		"Saf.",
		"Réb. 1",
		"Réb. 2",
		"Dsem. I",
		"Dsem. II",
		"Red.",
		"Sab.",
		"Ram.",
		"Sev.",
		"Dsül k.",
		"Dsül h."
	],
	"field-quarter-relative+0": "ez a negyedév",
	"field-minute-relative+0": "ebben a percben",
	"timeFormat-long": "H:mm:ss z",
	"field-quarter-relative+1": "következő negyedév",
	"field-wed-short-relative+-1": "előző szerda",
	"dateFormat-short": "GGGGG y. M. d.",
	"field-thu-short-relative+-1": "előző csütörtök",
	"field-year-narrow-relative+-1": "előző év",
	"days-standAlone-wide": [
		"vasárnap",
		"hétfő",
		"kedd",
		"szerda",
		"csütörtök",
		"péntek",
		"szombat"
	],
	"dateFormatItem-yyyyMMMEd": "G y. MMM d., E",
	"field-mon-narrow-relative+-1": "előző hétfő",
	"dateFormatItem-MMMMd": "MMMM d.",
	"field-thu-narrow-relative+-1": "előző csütörtök",
	"field-tue-narrow-relative+-1": "előző kedd",
	"dateFormatItem-H": "H",
	"dateFormatItem-yyyy": "G y.",
	"dayPeriods-standAlone-narrow-pm": "du.",
	"field-wed-short-relative+0": "ez a szerda",
	"months-standAlone-wide": [
		"Moharrem",
		"Safar",
		"Rébi I",
		"Rébi II",
		"Dsemádi I",
		"Dsemádi II",
		"Redseb",
		"Sabán",
		"Ramadán",
		"Sevvál",
		"Dsül kade",
		"Dsül hedse"
	],
	"field-wed-short-relative+1": "következő szerda",
	"field-sun-relative+-1": "előző vasárnap",
	"days-standAlone-abbr": [
		"V",
		"H",
		"K",
		"Sze",
		"Cs",
		"P",
		"Szo"
	],
	"dateFormatItem-hm": "a h:mm",
	"field-weekday": "hét napja",
	"field-day-short-relative+0": "ma",
	"field-quarter-narrow-relative+0": "ez a negyedév",
	"field-sat-relative+0": "ez a szombat",
	"field-day-short-relative+1": "holnap",
	"field-quarter-narrow-relative+1": "következő negyedév",
	"field-sat-relative+1": "következő szombat",
	"field-day-short-relative+2": "holnapután",
	"dateFormatItem-h": "a h",
	"field-week-short-relative+0": "ez a hét",
	"field-week-short-relative+1": "következő hét",
	"months-standAlone-abbr": [
		"Moh.",
		"Saf.",
		"Réb. 1",
		"Réb. 2",
		"Dsem. I",
		"Dsem. II",
		"Red.",
		"Sab.",
		"Ram.",
		"Sev.",
		"Dsül k.",
		"Dsül h."
	],
	"field-month-short-relative+0": "ez a hónap",
	"field-month-short-relative+1": "következő hónap",
	"timeFormat-full": "H:mm:ss zzzz",
	"dateFormatItem-MEd": "M. d., E",
	"dateFormatItem-y": "G y.",
	"field-thu-narrow-relative+0": "ez a csütörtök",
	"field-thu-narrow-relative+1": "következő csütörtök",
	"field-sun-narrow-relative+-1": "előző vasárnap",
	"field-mon-short-relative+-1": "előző hétfő",
	"field-thu-relative+0": "ez a csütörtök",
	"field-thu-relative+1": "következő csütörtök",
	"field-fri-short-relative+-1": "előző péntek",
	"dateFormatItem-hms": "a h:mm:ss",
	"field-thu-relative+-1": "előző csütörtök",
	"field-week": "hét",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"quarters-format-wide": [
		"I. negyedév",
		"II. negyedév",
		"III. negyedév",
		"IV. negyedév"
	],
	"dateFormatItem-Ed": "d., E",
	"field-wed-narrow-relative+0": "ez a szerda",
	"field-wed-narrow-relative+1": "következő szerda",
	"field-quarter-narrow-relative+-1": "előző negyedév",
	"field-year-short-relative+0": "ez az év",
	"dateFormatItem-yyyyMMM": "G y. MMM",
	"field-year-short-relative+1": "következő év",
	"field-fri-short-relative+0": "ez a péntek",
	"field-fri-short-relative+1": "következő péntek",
	"days-standAlone-short": [
		"V",
		"H",
		"K",
		"Sze",
		"Cs",
		"P",
		"Szo"
	],
	"field-week-short-relative+-1": "előző hét",
	"dateFormatItem-yyyyQQQQ": "G y. QQQQ",
	"field-hour-short": "óra",
	"quarters-format-abbr": [
		"N1",
		"N2",
		"N3",
		"N4"
	],
	"field-month-narrow": "hónap",
	"field-hour-narrow": "óra",
	"field-fri-narrow-relative+-1": "előző péntek",
	"field-year-relative+0": "ez az év",
	"field-year-relative+1": "következő év",
	"field-fri-relative+-1": "előző péntek",
	"eraNarrow": [
		"MF"
	],
	"field-tue-short-relative+-1": "előző kedd",
	"field-minute-narrow": "perc",
	"days-format-wide": [
		"vasárnap",
		"hétfő",
		"kedd",
		"szerda",
		"csütörtök",
		"péntek",
		"szombat"
	],
	"field-mon-narrow-relative+0": "ez a hétfő",
	"field-mon-narrow-relative+1": "következő hétfő",
	"field-year-short-relative+-1": "előző év",
	"field-zone": "időzóna",
	"dateFormatItem-MMMEd": "MMM d., E",
	"field-quarter-narrow": "negyedév",
	"field-sun-short-relative+-1": "előző vasárnap",
	"field-day-relative+-1": "tegnap",
	"dayPeriods-standAlone-abbr-am": "de.",
	"field-day-relative+-2": "tegnapelőtt",
	"days-format-abbr": [
		"V",
		"H",
		"K",
		"Sze",
		"Cs",
		"P",
		"Szo"
	],
	"field-sun-relative+0": "ez a vasárnap",
	"field-sun-relative+1": "következő vasárnap",
	"dateFormatItem-Gy": "G y.",
	"field-day-short": "nap",
	"field-week-narrow": "hét",
	"field-era": "éra",
	"field-fri-narrow-relative+0": "ez a péntek",
	"field-fri-narrow-relative+1": "következő péntek",
	"dayPeriods-standAlone-wide-am": "de."
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/hu/islamic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ez a negyedév",
	"field-quarter-short-relative+1": "következő negyedév",
	"field-tue-relative+-1": "előző kedd",
	"field-year": "év",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "ez a szerda",
	"field-wed-relative+1": "következő szerda",
	"timeFormat-short": "H:mm",
	"field-minute": "perc",
	"field-month-narrow-relative+-1": "előző hónap",
	"field-tue-narrow-relative+0": "ez a kedd",
	"field-tue-narrow-relative+1": "következő kedd",
	"field-thu-short-relative+0": "ez a csütörtök",
	"field-day-short-relative+-1": "tegnap",
	"field-thu-short-relative+1": "következő csütörtök",
	"field-day-relative+0": "ma",
	"field-day-short-relative+-2": "tegnapelőtt",
	"field-day-relative+1": "holnap",
	"field-week-narrow-relative+0": "ez a hét",
	"field-day-relative+2": "holnapután",
	"field-week-narrow-relative+1": "következő hét",
	"field-wed-narrow-relative+-1": "előző szerda",
	"dateFormatItem-EBhms": "E h:mm:ss",
	"field-year-narrow": "év",
	"field-era-short": "éra",
	"field-year-narrow-relative+0": "ez az év",
	"field-tue-relative+0": "ez a kedd",
	"field-year-narrow-relative+1": "következő év",
	"field-tue-relative+1": "következő kedd",
	"field-weekdayOfMonth": "hónap hétköznapja",
	"field-second-short": "másodperc",
	"dayPeriods-format-narrow-am": "de.",
	"dateFormatItem-MMMd": "MMM d.",
	"field-weekdayOfMonth-narrow": "hónap hétköznapja",
	"dayPeriods-format-abbr-am": "de.",
	"field-week-relative+0": "ez a hét",
	"field-month-relative+0": "ez a hónap",
	"field-week-relative+1": "következő hét",
	"field-month-relative+1": "következő hónap",
	"field-sun-narrow-relative+0": "ez a vasárnap",
	"timeFormat-medium": "H:mm:ss",
	"field-mon-short-relative+0": "ez a hétfő",
	"field-sun-narrow-relative+1": "következő vasárnap",
	"field-mon-short-relative+1": "következő hétfő",
	"field-second-relative+0": "most",
	"dateFormatItem-yyyyQQQ": "G y. QQQ",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"eraNames": [
		"MF"
	],
	"field-weekOfMonth": "hónap hete",
	"dayPeriods-standAlone-abbr-pm": "du.",
	"field-month-short": "hónap",
	"dateFormatItem-GyMMMEd": "G y. MMM d., E",
	"dateFormatItem-yyyyMd": "G y. MM. dd.",
	"field-day": "nap",
	"field-dayOfYear-short": "év napja",
	"field-year-relative+-1": "előző év",
	"dayPeriods-format-wide-am": "de.",
	"field-sat-short-relative+-1": "előző szombat",
	"field-hour-relative+0": "ebben az órában",
	"dateFormatItem-yyyyMEd": "G y. MM. dd., E",
	"field-wed-relative+-1": "előző szerda",
	"field-sat-narrow-relative+-1": "előző szombat",
	"field-second": "másodperc",
	"days-standAlone-narrow": [
		"V",
		"H",
		"K",
		"Sz",
		"Cs",
		"P",
		"Sz"
	],
	"dayPeriods-standAlone-wide-pm": "du.",
	"dateFormatItem-Ehms": "E h:mm:ss",
	"dateFormat-long": "G y. MMMM d.",
	"dateFormatItem-GyMMMd": "G y. MMM d.",
	"field-quarter": "negyedév",
	"field-week-short": "hét",
	"field-day-narrow-relative+0": "ma",
	"field-day-narrow-relative+1": "holnap",
	"field-day-narrow-relative+2": "holnapután",
	"quarters-standAlone-wide": [
		"1. negyedév",
		"2. negyedév",
		"3. negyedév",
		"4. negyedév"
	],
	"days-format-narrow": [
		"V",
		"H",
		"K",
		"Sz",
		"Cs",
		"P",
		"Sz"
	],
	"field-tue-short-relative+0": "ez a kedd",
	"field-tue-short-relative+1": "következő kedd",
	"field-month-short-relative+-1": "előző hónap",
	"field-mon-relative+-1": "előző hétfő",
	"dateFormatItem-GyMMM": "G y. MMM",
	"field-month": "hónap",
	"field-day-narrow": "nap",
	"field-minute-short": "perc",
	"field-dayperiod": "napszak",
	"field-sat-short-relative+0": "ez a szombat",
	"field-sat-short-relative+1": "következő szombat",
	"dayPeriods-format-narrow-pm": "du.",
	"dateFormat-medium": "G y. MMM d.",
	"dateFormatItem-yyyyMMMM": "G y. MMMM",
	"eraAbbr": [
		"MF"
	],
	"quarters-standAlone-abbr": [
		"1. n.év",
		"2. n.év",
		"3. n.év",
		"4. n.év"
	],
	"dayPeriods-format-abbr-pm": "du.",
	"dateFormatItem-yyyyM": "G y. MM.",
	"field-second-narrow": "mp",
	"field-mon-relative+0": "ez a hétfő",
	"field-mon-relative+1": "következő hétfő",
	"field-day-narrow-relative+-1": "tegnap",
	"field-year-short": "év",
	"field-day-narrow-relative+-2": "tegnapelőtt",
	"field-quarter-relative+-1": "előző negyedév",
	"dateFormatItem-yyyyMMMd": "G y. MMM d.",
	"field-dayperiod-narrow": "napszak",
	"dayPeriods-standAlone-narrow-am": "de.",
	"field-week-narrow-relative+-1": "előző hét",
	"days-format-short": [
		"V",
		"H",
		"K",
		"Sze",
		"Cs",
		"P",
		"Szo"
	],
	"quarters-format-narrow": [
		"I.",
		"II.",
		"III.",
		"IV."
	],
	"dayPeriods-format-wide-pm": "du.",
	"field-dayOfYear": "év napja",
	"field-sat-relative+-1": "előző szombat",
	"dateFormatItem-Md": "M. d.",
	"field-hour": "óra",
	"months-format-wide": [
		"Moharrem",
		"Safar",
		"Rébi el avvel",
		"Rébi el accher",
		"Dsemádi el avvel",
		"Dsemádi el accher",
		"Redseb",
		"Sabán",
		"Ramadán",
		"Sevvál",
		"Dsül kade",
		"Dsül hedse"
	],
	"dateFormat-full": "G y. MMMM d., EEEE",
	"field-month-relative+-1": "előző hónap",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "n.év",
	"field-sat-narrow-relative+0": "ez a szombat",
	"field-fri-relative+0": "ez a péntek",
	"field-sat-narrow-relative+1": "következő szombat",
	"field-fri-relative+1": "következő péntek",
	"dateFormatItem-EBhm": "E h:mm",
	"field-month-narrow-relative+0": "ez a hónap",
	"field-month-narrow-relative+1": "következő hónap",
	"field-sun-short-relative+0": "ez a vasárnap",
	"field-sun-short-relative+1": "következő vasárnap",
	"field-week-relative+-1": "előző hét",
	"field-quarter-short-relative+-1": "előző negyedév",
	"dateFormatItem-Ehm": "E h:mm",
	"months-format-abbr": [
		"Moh.",
		"Saf.",
		"Réb. 1",
		"Réb. 2",
		"Dsem. I",
		"Dsem. II",
		"Red.",
		"Sab.",
		"Ram.",
		"Sev.",
		"Dsül k.",
		"Dsül h."
	],
	"field-quarter-relative+0": "ez a negyedév",
	"field-minute-relative+0": "ebben a percben",
	"timeFormat-long": "H:mm:ss z",
	"field-quarter-relative+1": "következő negyedév",
	"field-wed-short-relative+-1": "előző szerda",
	"dateFormat-short": "GGGGG y. M. d.",
	"dateFormatItem-Bh": "B h",
	"field-thu-short-relative+-1": "előző csütörtök",
	"field-year-narrow-relative+-1": "előző év",
	"days-standAlone-wide": [
		"vasárnap",
		"hétfő",
		"kedd",
		"szerda",
		"csütörtök",
		"péntek",
		"szombat"
	],
	"dateFormatItem-yyyyMMMEd": "G y. MMM d., E",
	"field-mon-narrow-relative+-1": "előző hétfő",
	"dateFormatItem-MMMMd": "MMMM d.",
	"field-thu-narrow-relative+-1": "előző csütörtök",
	"field-tue-narrow-relative+-1": "előző kedd",
	"field-weekOfMonth-short": "hónap hete",
	"dateFormatItem-H": "H",
	"dayPeriods-standAlone-narrow-pm": "du.",
	"dateFormatItem-yyyy": "G y.",
	"field-wed-short-relative+0": "ez a szerda",
	"months-standAlone-wide": [
		"Moharrem",
		"Safar",
		"Rébi I",
		"Rébi II",
		"Dsemádi I",
		"Dsemádi II",
		"Redseb",
		"Sabán",
		"Ramadán",
		"Sevvál",
		"Dsül kade",
		"Dsül hedse"
	],
	"field-wed-short-relative+1": "következő szerda",
	"field-sun-relative+-1": "előző vasárnap",
	"days-standAlone-abbr": [
		"V",
		"H",
		"K",
		"Sze",
		"Cs",
		"P",
		"Szo"
	],
	"dateFormatItem-hm": "a h:mm",
	"field-weekday": "hét napja",
	"field-day-short-relative+0": "ma",
	"field-quarter-narrow-relative+0": "ez a negyedév",
	"field-day-short-relative+1": "holnap",
	"field-sat-relative+0": "ez a szombat",
	"field-quarter-narrow-relative+1": "következő negyedév",
	"field-day-short-relative+2": "holnapután",
	"field-sat-relative+1": "következő szombat",
	"dateFormatItem-h": "a h",
	"field-week-short-relative+0": "ez a hét",
	"field-week-short-relative+1": "következő hét",
	"months-standAlone-abbr": [
		"Moh.",
		"Saf.",
		"Réb. 1",
		"Réb. 2",
		"Dsem. I",
		"Dsem. II",
		"Red.",
		"Sab.",
		"Ram.",
		"Sev.",
		"Dsül k.",
		"Dsül h."
	],
	"field-dayOfYear-narrow": "év napja",
	"field-month-short-relative+0": "ez a hónap",
	"field-month-short-relative+1": "következő hónap",
	"field-weekdayOfMonth-short": "hónap hétköznapja",
	"timeFormat-full": "H:mm:ss zzzz",
	"dateFormatItem-MEd": "M. d., E",
	"field-zone-narrow": "időzóna",
	"dateFormatItem-y": "G y.",
	"field-thu-narrow-relative+0": "ez a csütörtök",
	"field-thu-narrow-relative+1": "következő csütörtök",
	"field-sun-narrow-relative+-1": "előző vasárnap",
	"field-mon-short-relative+-1": "előző hétfő",
	"field-thu-relative+0": "ez a csütörtök",
	"field-thu-relative+1": "következő csütörtök",
	"field-fri-short-relative+-1": "előző péntek",
	"dateFormatItem-hms": "a h:mm:ss",
	"field-thu-relative+-1": "előző csütörtök",
	"field-week": "hét",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"quarters-format-wide": [
		"I. negyedév",
		"II. negyedév",
		"III. negyedév",
		"IV. negyedév"
	],
	"dateFormatItem-Ed": "d., E",
	"field-wed-narrow-relative+0": "ez a szerda",
	"field-wed-narrow-relative+1": "következő szerda",
	"field-quarter-narrow-relative+-1": "előző negyedév",
	"field-year-short-relative+0": "ez az év",
	"field-dayperiod-short": "napszak",
	"dateFormatItem-yyyyMMM": "G y. MMM",
	"field-year-short-relative+1": "következő év",
	"field-fri-short-relative+0": "ez a péntek",
	"field-fri-short-relative+1": "következő péntek",
	"days-standAlone-short": [
		"V",
		"H",
		"K",
		"Sze",
		"Cs",
		"P",
		"Szo"
	],
	"field-week-short-relative+-1": "előző hét",
	"dateFormatItem-yyyyQQQQ": "G y. QQQQ",
	"field-hour-short": "óra",
	"field-zone-short": "időzóna",
	"quarters-format-abbr": [
		"I. n.év",
		"II. n.év",
		"III. n.év",
		"IV. n.év"
	],
	"field-month-narrow": "hónap",
	"field-hour-narrow": "ó",
	"field-fri-narrow-relative+-1": "előző péntek",
	"field-year-relative+0": "ez az év",
	"field-year-relative+1": "következő év",
	"field-era-narrow": "éra",
	"field-fri-relative+-1": "előző péntek",
	"eraNarrow": "MF",
	"dateFormatItem-Bhms": "B h:mm:ss",
	"field-tue-short-relative+-1": "előző kedd",
	"field-minute-narrow": "p",
	"days-format-wide": [
		"vasárnap",
		"hétfő",
		"kedd",
		"szerda",
		"csütörtök",
		"péntek",
		"szombat"
	],
	"field-mon-narrow-relative+0": "ez a hétfő",
	"field-mon-narrow-relative+1": "következő hétfő",
	"field-year-short-relative+-1": "előző év",
	"field-zone": "időzóna",
	"dateFormatItem-MMMEd": "MMM d., E",
	"field-weekOfMonth-narrow": "hónap hete",
	"field-weekday-narrow": "hét napja",
	"field-quarter-narrow": "n.év",
	"field-sun-short-relative+-1": "előző vasárnap",
	"field-day-relative+-1": "tegnap",
	"dayPeriods-standAlone-abbr-am": "de.",
	"field-day-relative+-2": "tegnapelőtt",
	"field-weekday-short": "hét napja",
	"days-format-abbr": [
		"V",
		"H",
		"K",
		"Sze",
		"Cs",
		"P",
		"Szo"
	],
	"dateFormatItem-Bhm": "B h:mm",
	"field-sun-relative+0": "ez a vasárnap",
	"field-sun-relative+1": "következő vasárnap",
	"dateFormatItem-Gy": "G y.",
	"field-day-short": "nap",
	"field-week-narrow": "hét",
	"field-era": "éra",
	"field-fri-narrow-relative+0": "ez a péntek",
	"field-fri-narrow-relative+1": "következő péntek",
	"dayPeriods-standAlone-wide-am": "de."
}
//end v1.x content
);
